/**
 * Tab control for tab displays.
 */

(function ($) {

    function s360_tabcontrol() {
        // initialization
        $('[data-tabcontrol-for]:not(.initialized)').each(function (index, elem) {

            // collect data
            var $tabControl = $(elem);
            var $buttonsContainer = $tabControl.find('.s360-horizontal-tab-buttons');
            if (!$buttonsContainer.length) {
                return;
            }
            var $buttons = $tabControl.find('.s360-tab-button');
            if (!$buttons.length) {
                return;
            }
            var $tabContainer = $($tabControl.data('tabcontrol-for'));
            if (!$tabContainer.length) {
                return;
            } else {

            }
            var $tabs = $tabContainer.find('.s360-tab-content');
            if (!$tabs.length) {
                return;
            }
            var $tabPrev = $tabControl.find('.s360-horizontal-tabs-prev');
            var $tabNext = $tabControl.find('.s360-horizontal-tabs-next');
            $tabControl.data('tabcontrol-buttonscontainer', $buttonsContainer);
            $tabControl.data('tabcontrol-buttons', $buttons);
            $tabControl.data('tabcontrol-tabcontainer', $tabContainer);
            $tabControl.data('tabcontrol-tabs', $tabs);
            $tabControl.data('tabcontrol-prev', $tabPrev);
            $tabControl.data('tabcontrol-next', $tabNext);

            // bind events for tab control buttons
            $buttons.each(function () {
                var $button = $(this);
                $button.click(function (e) {
                    e.preventDefault();
                    var $targetTab = $($button.attr('href'));
                    if ($targetTab.length) {
                        $buttons.removeClass('active');
                        $button.addClass('active');
                        $tabs.removeClass('active');
                        $targetTab.first().addClass('active');
                    }
                });
            });

            // check the window location hash for a preselected tab
            if(typeof window.location.hash !== "undefined" && window.location.hash) {
                $buttons.filter('[href="'+window.location.hash+'"]').click();
            }

            // set initial left offset value for the buttonsContainer
            $buttonsContainer.css('left', 0);

            var buttonsWidth = 0;
            $buttons.each(function (index, elem) {
                buttonsWidth += $(elem).outerWidth(true);
            });
            $tabControl.data('tabcontrol-buttons-width', buttonsWidth);

            var getStepSize = function() {
                // the step size is dependend on the viewport width
                return $tabControl.width();
            };

            var updateButtonsContainer = function(direction) {
                var currentOffset = Number($buttonsContainer.css('left').replace('px', ''));
                var viewportWidth = $tabControl.width();

                // do nothing if the currentOffset + buttonsWidth < viewportWidth
                if(currentOffset + buttonsWidth < viewportWidth) {
                    return;
                }

                var newOffset = 0;
                if(direction === 'next') {
                    var maxOffset = viewportWidth - buttonsWidth;
                    newOffset = Math.max(maxOffset, currentOffset - getStepSize());
                } else {
                    newOffset = Math.min(0, currentOffset + getStepSize());
                }
                $buttonsContainer.css('left', newOffset + 'px');
                // update button visibility
                $tabPrev.hide();
                $tabNext.hide();
                if (newOffset + buttonsWidth > viewportWidth) {
                    $tabNext.show();
                }
                if (newOffset < 0) {
                    $tabPrev.show();
                }
            };

            if ($tabPrev.length && $tabNext.length) {
                // bind events for tab button slider
                $tabPrev.click(function (e) {
                    e.preventDefault();
                    e.stopPropagation();
                    updateButtonsContainer('prev');
                });
                $tabNext.click(function (e) {
                    e.preventDefault();
                    e.stopPropagation();
                    updateButtonsContainer('next');
                });
            }
            $buttonsContainer.on('swipeleft', function(e) {
                e.preventDefault();
                e.stopPropagation();
                updateButtonsContainer('next');
            });
            $buttonsContainer.on('swiperight', function(e) {
                e.preventDefault();
                e.stopPropagation();
                updateButtonsContainer('prev');
            });


            // signal complete initialization
            $tabControl.addClass('initialized');
        });
        // handle layout for initialized controls, note that this is done by moving the buttonsContainer to the left with negative values or to the right until it reaches 0
        $('[data-tabcontrol-for].initialized').each(function (index, elem) {
            var $tabControl = $(elem);
            var $buttonsContainer = $tabControl.data('tabcontrol-buttonscontainer');
            var buttonsWidth = $tabControl.data('tabcontrol-buttons-width');
            var $tabPrev = $tabControl.data('tabcontrol-prev');
            var $tabNext = $tabControl.data('tabcontrol-next');

            // viewport width is dynamic
            var viewportWidth = $tabControl.width();

            $tabPrev.hide();
            $tabNext.hide();

            if (buttonsWidth < viewportWidth) {
                // disable slide navi if everything fits, also set the container to its initial position
                $buttonsContainer.css('left', 0);
                return;
            }

            // get current offset of the button container
            var offsetButtonsContainer = Number($buttonsContainer.css('left').replace('px', ''));
            // determine if we need to show prev and next
            // next is shown only if offset + buttonsWidth is greater than the viewport width
            if (offsetButtonsContainer + buttonsWidth > viewportWidth) {
                $tabNext.show();
            }
            // prev is shown only if the offset is smaller than 0
            if (offsetButtonsContainer < 0) {
                $tabPrev.show();
            }
        });
    }

    function s360_tabcontrol_register_targets() {
        $('#product-offer #jump-to-votes-tab').click(function () {
            $('[data-tabcontrol-for].initialized a[href!="#tab-votes"]').removeClass('active');
            $('[data-tabcontrol-for].initialized a[href="#tab-votes"]').addClass('active');
        });
        $('#product-offer a[href="#tab-description"]').click(function() {
            $('[data-tabcontrol-for].initialized a[href="#tab-description"]').tab('show');
            $('[data-tabcontrol-for].initialized a[href!="#tab-description"]').removeClass('active');
            $('[data-tabcontrol-for].initialized a[href="#tab-description"]').addClass('active');
        });
    }


    // CALLS
    // ===============
    $(window).load(function () {
        s360_tabcontrol();
        s360_tabcontrol_register_targets();
        var debounced = _.debounce(function () {
            s360_tabcontrol();
        }, 16);
        $(window).resize(debounced);
        $('body').on('article-variation-loaded.s360', function() {
            s360_tabcontrol();
            s360_tabcontrol_register_targets();
        });
    });
})(jQuery);
